@@ -48,7 +48,7 @@ class PyTorchRichModuleProcessor:
     @staticmethod
     def describe(obj, **kwargs):
         from torchinfo import summary
-        summary(obj, **kwargs)
+        return summary(obj, **kwargs)
 
 
 PROCESSORS = [
@@ -64,7 +64,8 @@ def what(obj, *args, **kwargs):
     print(f"Processing type {type(obj)}")
     for processor in PROCESSORS:
         if processor.can(obj, **kwargs):
-            return(processor.describe(obj, **kwargs))
+            print(f"Using processor: {processor}")
+            return processor.describe(obj, **kwargs) 
             break
     else:
         print(f"Couldn't figure out what {obj} is")
